@@ -6,13 +6,15 @@ $FTP="/bin/ftp";
 $RPCINFO="/usr/sbin/rpcinfo";
 $RUSERS="/usr/bin/rusers";
 $RUP="/usr/bin/rup";
-$SHOWMOUNT="/usr/sbin/showmount";
+$SHOWMOUNT="bin/showmount";
 $YPWHICH="/usr/bin/ypwhich";
 $NSLOOKUP="/usr/bin/nslookup";
+$DIG="/usr/bin/dig";
 $XHOST="/usr/bin/X11/xhost";
 $PING="/bin/ping";
-$MOSAIC="/usr/bin/lynx";
+$MOSAIC="/usr/local/netscape/netscape";
 $TCP_SCAN="bin/tcp_scan";
+$FTP_SCAN="bin/ftp-scan";
 $UDP_SCAN="bin/udp_scan";
 $FPING="bin/fping";
 $NFS_CHK="bin/nfs-chk";
@@ -27,3 +29,9 @@ $TPING="bin/tping";
 $SAINT_CF="config/saint.cf";
 $SERVICES="config/services";
 $CAT="/bin/cat";
+$MKNOD="/bin/mknod";
+$MKFIFO="/bin/mkfifo";
+$NMBLOOKUP="/usr/sbin/nmblookup";
+$SMBCLIENT="/usr/bin/smbclient";
+$NMAP="/usr/local/bin/nmap";
+$DDOS="bin/ddos_scan";
