@@ -7,6 +7,7 @@
 # variables below are global. Perhaps we should hide in our own package
 # name space.
 #
+my($rnd) = time();
 @cf_attack_level = ();	$cf_attack_level[$attack_level] = "checked";
 @cf_timeout = ();	$cf_timeout[$timeout] = "checked";
 @cf_sub_zero = ();	$cf_sub_zero[$sub_zero_proximity] = "checked";
@@ -15,12 +16,13 @@
 @cf_dont_nslookup = ();	$cf_dont_nslookup[$dont_use_nslookup] = "checked";
 @cf_dont_ping = ();	$cf_dont_ping[$dont_use_ping] = "checked";
 @cf_untrusted = ();	$cf_untrusted[$untrusted_host] = "checked";
+@cf_extreme = ();	$cf_extreme[$extreme] = "checked";
 
 print CLIENT <<EOF
 <HTML>
 <HEAD>
 <TITLE>SAINT Configuration Management</TITLE>
-<LINK REV="made" HREF="mailto:saint\@wwdsi.com">
+<LINK REV="made" HREF="mailto:saint\@saintcorporation.com">
 </HEAD>
 <BODY BGCOLOR="white" vlink="#000000" link="#04289D">
 
@@ -35,7 +37,7 @@ print CLIENT <<EOF
 	  <TD WIDTH="86" VALIGN="TOP">
 	    <TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0">
 		<TR>
-		    <TD WIDTH="86"><A HREF="http://www.wwdsi.com"><IMG SRC="$HTML_ROOT/images/wwdsi_logo.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="WWDSI"
+		    <TD WIDTH="86"><A HREF="http://www.saintcorporation.com"><IMG SRC="$HTML_ROOT/images/home.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="SAINT Corporation"
 			BORDER="0"></A></TD>
 		</TR>
 		<TR>
@@ -98,9 +100,20 @@ Heavy
 <DT><DD><INPUT TYPE="radio" NAME=attack_level VALUE=3 $cf_attack_level[3]>
 Heavy+
 <DT><DD><INPUT TYPE="radio" NAME=attack_level VALUE=4 $cf_attack_level[4]>
-Top 10 (scans specifically for
-<A HREF="http://www.sans.org/topten.htm">SANS Top 10 Internet Security
-Threats</A>)
+Top 20 (scans specifically for
+<A HREF="http://www.sans.org/top20.htm">SANS Top 20 Internet Security
+Vulnerabilities</A>)
+<DT><DD><INPUT TYPE="radio" NAME=attack_level VALUE=5 $cf_attack_level[5]>
+Custom: <SELECT NAME=custom_level>
+EOF
+;
+for (@custom_levels) {
+	$selected = ($custom_level eq $_) ? " selected" : "";
+	print CLIENT "<OPTION$selected>$_</OPTION>\n";
+}
+print CLIENT <<EOF
+</SELECT>
+(<A HREF="saint_custom_select.pl,cf,$rnd">Set up custom scan</A>)
 </DL>
 
 <P>
@@ -163,7 +176,8 @@ Maximal proximity
 
 <P>
 <STRONG>As I move out to less proximate hosts, how much should I drop
-the probe level?</STRONG>
+the probe level?</STRONG> (Only used with light, medium, heavy,
+and heavy+ scan levels)
 <DL compact>
 <DT><DD><INPUT SIZE=3 NAME=proximity_descent VALUE=$proximity_descent>
 Proximity descent
@@ -178,7 +192,8 @@ Proximity descent
 
 <P>
 <STRONG>Should I do subnet expansion; that is, should I probe just the
-target or its entire subnet?</STRONG>
+target or its entire subnet?</STRONG> (Choosing just the target
+will disable the smurf/fraggle check.)
 <DL compact>
 <DT><DD><INPUT TYPE="radio" NAME=attack_proximate_subnets VALUE=0
 	$cf_attack_proximate[0]>Just the target
@@ -198,6 +213,18 @@ You are running SAINT from a possibly trusted host
 You are running SAINT from an untrusted host
 </DL>
 
+<P>
+<STRONG>Targets' Netmask(s).</STRONG> For best
+results, change this if your targets use unusual
+subnetting. 255.255.255.0 is a Class C network.
+Be very careful if you go below this (e.g. 255.255.254.0)
+or you could scan outside your Class C.
+<DL compact>
+<DT><DD><INPUT TYPE=text SIZE=40 NAME=target_netmask VALUE="$target_netmask">
+Netmask
+</DL>
+
+<P>
 <HR>
 
 <h2>Patterns specifying hosts to limit the probe to</h2>
@@ -239,6 +266,26 @@ or an internet domain suffix.
 
 <hr>
 
+<H2>Whether to perform dangerous tests</H2>
+
+Performing dangerous tests such as buffer overflows may
+help reduce false alarms, but <b>may crash services on target
+hosts!</b> (If a service crashes, further tests against that service
+may result in false negatives.) See the <A HREF="$HTML_ROOT/docs/saint.cf.html#extreme-list">list of dangerous tests</A>.
+<P>
+<I>Note:</I> if you do not choose to perform dangerous tests,
+SAINT will report a potential problem if there is a
+possibility that the vulnerability exists.
+
+<DL compact>
+<DT><DD><INPUT TYPE="radio" NAME=extreme VALUE=0 $cf_extreme[0]>
+Do not perform dangerous tests.
+<DT><DD><INPUT TYPE="radio" NAME=extreme VALUE=1 $cf_extreme[1]>
+Do perform dangerous tests. <b><i>Caution!</i></b>
+</DL>
+
+<hr>
+
 <H2>Workarounds for broken DNS, ICMP etc.</H2>
 
 <DL compact>
@@ -255,6 +302,15 @@ Ping hosts to see if they are alive (skip non-responding hosts).
 Don't ping hosts: ICMP does not work.
 </DL>
 
+<P>
+<STRONG>Standard Ports</STRONG>
+TCP ports to scan to determine whether a host is alive
+when <I>don't ping hosts</I> is selected above or firewall
+mode is enabled.
+<DL compact>
+<DT><DD><INPUT TYPE="text" NAME="std_ports" SIZE=30 VALUE="$std_ports">
+</DL>
+<P>
 <HR>
 <INPUT TYPE="submit" VALUE="Change the configuration file">
 </FORM>
