@@ -2,7 +2,7 @@ print CLIENT <<EOF;
 <HTML>
 <HEAD>
 <title>SAINT Reporting and Analysis</title>
-<LINK REV="made" HREF="mailto:saint\@wwdsi.com">
+<LINK REV="made" HREF="mailto:saint\@saintcorporation.com">
 </HEAD>
 <BODY BGCOLOR="white" vlink="#000000" link="#04289D">
 
@@ -17,7 +17,7 @@ print CLIENT <<EOF;
 	  <TD WIDTH="86" VALIGN="TOP">
 	    <TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0">
 		<TR>
-		    <TD WIDTH="86"><A HREF="http://www.wwdsi.com"><IMG SRC="$HTML_ROOT/images/wwdsi_logo.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="WWDSI"
+		    <TD WIDTH="86"><A HREF="http://www.saintcorporation.com"><IMG SRC="$HTML_ROOT/images/home.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="SAINT Corporation"
 			BORDER="0"></A></TD>
 		</TR>
 		<TR>
@@ -67,6 +67,7 @@ print CLIENT <<EOF;
         <li> <a href=saint_severity_types.pl> By Type of Vulnerability </a>
         <li> <a href=saint_severity_counts.pl> By Vulnerability Count </a>
         </ul>
+<p>
 
 <strong> Host Information </strong>
         <ul>
@@ -84,7 +85,14 @@ print CLIENT <<EOF;
         <li> <a href=saint_info_trusting.pl> Trusting Hosts</a>
 	</ul>
 <p>
-
+<a href=saintwriter/saintwriter_form.pl> SAINTwriter</a>
+<p>
+<strong> Exclusions</strong>
+       <ul>
+         <li> <a href="saint_exclusion_manage_form.pl">Manage exclusions</A>
+         <li> <a href="saint_exclusion_list.pl">List exclusions</A>
+       </ul>
+<p>
 <HL>
 </UL></UL>
 	  </TD>
