@@ -3,79 +3,25 @@
 #
 ($_host, $_show_all_services) = split(/,/, $html_script_args);
 ($_type = $hosttype{$_host}) =~ tr / \//?!/;
+my $myurl="saint_info_host.pl,$html_script_args";
 
-print CLIENT <<EOF;
-<HTML>
-<HEAD>
-<title> Results - $_host </title>
-<LINK REV="made" HREF="mailto:saint\@wwdsi.com">
-</HEAD>
-<BODY BGCOLOR="white" vlink="#000000" link="#04289D">
+&generate_html_header(\*::CLIENT,"Results - $_host");
 
-<P></P>
-
-<P>
-<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0">
-	<TR>
-		<TD COLSPAN="2"><IMG SRC="$HTML_ROOT/images/data_analysis_banner.gif" WIDTH="621" HEIGHT="106" ALIGN="BOTTOM" ALT="Data Analysis" BORDER="0"></TD>
-	</TR>
-	<TR>
-	  <TD WIDTH="86" VALIGN="TOP">
-	    <TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0">
-		<TR>
-		    <TD WIDTH="86"><A HREF="http://www.wwdsi.com"><IMG SRC="$HTML_ROOT/images/wwdsi_logo.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="WWDSI"
-			BORDER="0"></A></TD>
-		</TR>
-		<TR>
-		    <TD WIDTH="86"><A HREF="$HTML_ROOT/saint.html"><IMG SRC="$HTML_ROOT/images/home_button.gif" WIDTH="86" HEIGHT="46"
-			ALIGN="BOTTOM" ALT="SAINT Home" BORDER="0" STYLE="Background-Image : none"></A></TD>
-		</TR>
-		<TR>
-		    <TD WIDTH="86"><A HREF="$HTML_SERVER/data/saint_data_form.pl"><IMG SRC="$HTML_ROOT/images/data_mgmt_button.gif" WIDTH="86"
-			HEIGHT="46" ALIGN="BOTTOM" ALT="Data Management" BORDER="0"></A></TD>
-		</TR>
-		<TR>
-		    <TD WIDTH="86"><A HREF="$HTML_SERVER/running/saint_run_form.pl"><IMG SRC="$HTML_ROOT/images/target_selection_button.gif"
-			WIDTH="86" HEIGHT="46" ALIGN="BOTTOM" ALT="Target Selection" BORDER="0"></A></TD>
-		</TR>
-		<TR>
-		    <TD WIDTH="86"><A HREF="$HTML_SERVER/reporting/analysis.pl"><IMG SRC="$HTML_ROOT/images/data_analysis_button.gif" WIDTH="86"
-			HEIGHT="46" ALIGN="BOTTOM" ALT="Data Analysis" BORDER="0"></A></TD>
-		</TR>
-		<TR>
-		    <TD WIDTH="86"><A HREF="$HTML_SERVER/admin/saint_cf_form.pl"><IMG SRC="$HTML_ROOT/images/config_mgmt_button.gif" WIDTH="86"
-			HEIGHT="46" ALIGN="BOTTOM" ALT="Configuration Management" BORDER="0"></A></TD>
-		</TR>
-		<TR>
-		    <TD WIDTH="86"><A HREF="$HTML_ROOT/saint_documentation.html"><IMG SRC="$HTML_ROOT/images/documentation_button.gif"
-			WIDTH="86" HEIGHT="46" ALIGN="BOTTOM" ALT="SAINT Documentation" BORDER="0"></A></TD>
-		</TR>
-		<TR>
-		    <TD WIDTH="86" HEIGHT="46"><A HREF="$HTML_ROOT/docs/FAQ.html#trouble"><IMG SRC="$HTML_ROOT/images/troubleshooting_button.gif" WIDTH="86"
-			HEIGHT="46" ALIGN="BOTTOM" ALT="Troubleshooting" BORDER="0"></A></TD>
-		</TR>
-		<TR>
-		    <TD WIDTH="86" HEIGHT="65"><IMG SRC="$HTML_ROOT/images/bottom_border.gif" WIDTH="86" HEIGHT="75" ALIGN="BOTTOM" ALT="--------" BORDER="0"></TD>
-		</TR>
-	    </TABLE>
-	  </TD>
-	  <TD VALIGN="TOP">
-		<DL>
-			<P>
-		</DL>
+print CLIENT <<EOF
 <CENTER><H1>Results - $_host </H1></CENTER>
 <hr><UL><UL>
 <h3>General host information:</h3>
-<ul>
+<dl>
 EOF
+;
 
 #
 # Refresh the host type and service tables.
 #
-&make_hosttype_info();
-&make_service_info();
-&make_subnet_info();
-&make_severity_info();
+&make_hosttype_exclusion_info();
+&make_service_exclusion_info();
+&make_subnet_exclusion_info();
+&make_severity_exclusion_info();
 
 $_exists = 0;
 $_dot = "blackdot";
@@ -109,8 +55,6 @@ EOF
 	$_exists = 1;
 }
 
-
-
 if (exists($all_hosts{$_host})) {
 	($_subnet = $all_hosts{$_host}{IP}) =~ s/\.[^.]*$//;
         $_dot = "blackdot";
@@ -142,7 +86,7 @@ EOF
 }
 
 if (exists($all_hosts{$_host}) && defined($all_hosts{$_host}{'attack'})) {
-	@_level = ('none', 'light', 'normal', 'heavy', 'heavyplus', 'top 10');
+	@_level = ('none', 'light', 'normal', 'heavy', 'heavyplus', 'top 20', 'custom');
 	print CLIENT <<EOF;
         <dt><IMG SRC="$HTML_ROOT/dots/$_dot.gif" ALT="$_alt">
 	Scanning level: @_level[1 + $all_hosts{$_host}{'attack'}]
@@ -161,7 +105,7 @@ EOF
 }
 
 
-print CLIENT "</ul>\n";
+print CLIENT "</dl>\n";
 
 
 if (exists($server_info{$_host}) || exists($other_server_info{$_host})) {
@@ -182,7 +126,6 @@ EOF
 	  $_count = split(/\n/, $other_server_info{$_host});
 	  if (($_count < 5) || $_show_all_services) {
 	    for (sort split(/\n/, $other_server_info{$_host})) {
-		($_service = $_) =~ tr / \//?!/;
 		print CLIENT <<EOF;
 		<dt><IMG SRC="$HTML_ROOT/dots/$_dot.gif" ALT="$_alt">
 		$_ server
@@ -203,8 +146,14 @@ print CLIENT <<EOF;
 </ul>
 EOF
 
-if (exists($severity_host_type_info{$_host})) {
-	print CLIENT "<h3>Vulnerable Services:</h3><ul>\n";
+my $txtstr=
+     get_host_vulnerability_count_string($_host,$Exclusions::display_ignored);
+my $color;
+
+if (exists($severity_host_type_info{$_host}) &&
+      ( $Exclusions::display_ignored ||
+      any_nonexcluded_facts_by_host($_host)))
+{     print CLIENT "<h3>Vulnerability information:  $txtstr</h3><dl>\n";
 	for (keys %{$severity_host_type_info{$_host}}) {
 		($_tutorials = $_) =~ tr / /_/;
 		for (sort split(/\n/, $severity_host_type_info{$_host}{$_})) {
@@ -218,36 +167,33 @@ if (exists($severity_host_type_info{$_host})) {
 			} else {
 			    $cve_ref = "";
 			}
-			if ($top10{$text} =~ /yes/) {
-			    $top10_ref = "<IMG SRC=\"$HTML_ROOT/images/top10.jpg\" ALT=\"top-10\">";
+			if ($top20{$text} =~ /yes/) {
+			    $top20_ref = "<IMG SRC=\"$HTML_ROOT/images/top20.gif\" ALT=\"top-20\">";
 			} else {
-			    $top10_ref = "";
+			    $top20_ref = "";
 			}
-                         if($severity_brown_type_info{$service_output}) {
-                            $_dot = "browndot";
-                            $_alt = "BROWN";
-                         } elsif ($severity_green_type_info{$service_output}) {
-                            $_dot = "greendot";
-                            $_alt = "GREEN";
-                         } elsif ($severity_yellow_type_info{$service_output}) {
-                            $_dot = "yellowdot";
-                            $_alt = "YELLOW";
-                         } elsif ($severity_red_type_info{$service_output}) {
-                            $_dot = "reddot";
-                            $_alt = "RED";
+                         if($severity =~ /^z/) {
+                            $color = "BROWN";
+                         } elsif ($severity =~ /^y/) {
+                            $color = "YELLOW";
                          } else {
-                            $_dot = "blackdot";
+                            $color = "RED";
                          }
-			print CLIENT <<EOF;
-        <dt><IMG SRC="$HTML_ROOT/dots/$_dot.gif" ALT="$_alt">$top10_ref
-	<A HREF="$HTML_ROOT/tutorials/vulnerability/$_tutorials.html">$text</A> $cve_ref
+                      $txtstr=<<EOF;
+$top20_ref
+<A HREF="$HTML_ROOT/tutorials/vulnerability/$_tutorials.html">$text</A>
+$cve_ref
 EOF
+                      print_vulnerability_by_host_line(\*::CLIENT,
+                              $txtstr, $color, $_, $myurl,
+                              $Exclusions::display_ignored
+);
 		}
 	}
 	$_exists = 1;
 }
 print CLIENT <<EOF;
-</ul>
+</dl>
 EOF
 
 # List host service info
@@ -256,10 +202,14 @@ if ($_exists) {
         $_dot = "blackdot";
 	$_alt = "BLACK";
 	print CLIENT <<EOF;
-	<h3>Actions:</h3> <ul>
+	<h3>Actions:</h3> <dl>
         <dt><IMG SRC="$HTML_ROOT/dots/$_dot.gif" ALT="$_alt">
 	<A HREF="$HTML_SERVER/running/saint_run_form.pl,$_host,">Scan this host</a>
 EOF
+      print_show_hide_html_message(\*::CLIENT,$myurl,
+              "<dt><IMG SRC=\"$HTML_ROOT/dots/$_dot.gif\" ALT=\"$_alt\">",
+              "<\dt>");
+      print CLIENT "\n</dl>\n";
 } else {
 	print CLIENT <<EOF;
 	<h3>No information found on host $_host.</h3>
@@ -270,9 +220,6 @@ print CLIENT <<EOF;
 <hr> <a href=$HTML_STARTPAGE> Back to the SAINT start page </a> |
 <a href=analysis.pl> Back to SAINT Reporting and Analysis </a>
 </UL></UL>
-	  </TD>
-	</TR>
-</TABLE>
-</BODY>
-</HTML>
 EOF
+
+&generate_html_footer(\*::CLIENT);
