@@ -3,6 +3,7 @@
 #
 
 # generate the tables for looking subnets/hosts in:
+my $myurl = "saint_info_subnet.pl";
 &make_subnet_info();
 $_subnets = keys %all_subnets;
 
@@ -13,11 +14,15 @@ sub sort_ip {
     return $aip <=> $bip;
 }
 
+my $txtstr="vulnerable/total";
+if ( $Exclusions::display_ignored) {  $txtstr="vulnerable[
+ignored]/total"; }
+
 print CLIENT <<EOF;
 <HTML>
 <HEAD>
 <title> Host Tables - By Subnet  </title>
-<LINK REV="made" HREF="mailto:saint\@wwdsi.com">
+<LINK REV="made" HREF="mailto:saint\@saintcorporation.com">
 </HEAD>
 <BODY BGCOLOR="white" vlink="#000000" link="#04289D">
 
@@ -32,7 +37,7 @@ print CLIENT <<EOF;
 	  <TD WIDTH="86" VALIGN="TOP">
 	    <TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0">
 		<TR>
-		    <TD WIDTH="86"><A HREF="http://www.wwdsi.com"><IMG SRC="$HTML_ROOT/images/wwdsi_logo.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="WWDSI"
+		    <TD WIDTH="86"><A HREF="http://www.saintcorporation.com"><IMG SRC="$HTML_ROOT/images/home.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="SAINT Corporation"
 			BORDER="0"></A></TD>
 		</TR>
 		<TR>
@@ -74,8 +79,8 @@ print CLIENT <<EOF;
 		</DL>
 <CENTER><H1>Host Tables - By Subnet </H1></CENTER>
 <hr><UL><UL>
-<h3>$_subnets Subnets. Number of hosts per subnet (vulnerable/total). </h3>
-<strong>Subnets with a red dot next to them have a vulnerable host contained within.</strong>
+<h3>$_subnets Subnets. Number of hosts per subnet ($txtstr). </h3>
+<strong>Subnets with a red dot next to them have a vulnerable host contained within (not counting ignored vulnerabilities).</strong>
 <ul>
 EOF
 
@@ -89,6 +94,8 @@ for $_net (sort sort_ip keys %all_subnets) {
 EOF
     }
 
+print_show_hide_html_message(\*::CLIENT,$myurl);
+
 print CLIENT <<EOF;
 </ul>
 <hr> <a href=$HTML_STARTPAGE> Back to the SAINT start page </a> |
