@@ -2,12 +2,13 @@
 # List all hosts in a subnet
 #
 ($_subnet, $_sort_order) = split(/,/, $html_script_args);
+&recalc_host_severity_count;
 
 print CLIENT <<EOF;
 <HTML>
 <HEAD>
 <title> Host Table - Subnet $_subnet</title>
-<LINK REV="made" HREF="mailto:saint\@wwdsi.com">
+<LINK REV="made" HREF="mailto:saint\@saintcorporation.com">
 </HEAD>
 <BODY BGCOLOR="white" vlink="#000000" link="#04289D">
 
@@ -22,7 +23,7 @@ print CLIENT <<EOF;
 	  <TD WIDTH="86" VALIGN="TOP">
 	    <TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0">
 		<TR>
-		    <TD WIDTH="86"><A HREF="http://www.wwdsi.com"><IMG SRC="$HTML_ROOT/images/wwdsi_logo.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="WWDSI"
+		    <TD WIDTH="86"><A HREF="http://www.saintcorporation.com"><IMG SRC="$HTML_ROOT/images/home.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="SAINT Corporation"
 			BORDER="0"></A></TD>
 		</TR>
 		<TR>
