@@ -3,6 +3,7 @@
 # override some defaults.
 #
 ($_host) = split(/,/, $html_script_args);
+my($rnd) = time();
 
 #
 # First figure out what radio buttons etc. should be "on". Note: the
@@ -13,6 +14,7 @@
 @check_subnets = ();	$check_subnets[$attack_proximate_subnets] = "checked";
 @check_level = ();	$check_level[$attack_level] = "checked";
 @check_firewall = ();	$check_firewall[$firewall_flag] = "checked";
+@check_extreme = ();	$check_extreme[$extreme] = "checked";
 
 #
 # In case the primary target has not yet been set.
@@ -24,8 +26,7 @@ print CLIENT <<EOF
 <HTML>
 <HEAD>
 <TITLE>SAINT Target Selection</TITLE>
-<LINK REV="made" HREF="mailto:satan\@fish.com">
-<LINK REV="made" HREF="mailto:saint\@wwdsi.com">
+<LINK REV="made" HREF="mailto:saint\@saintcorporation.com">
 </HEAD>
 <BODY BGCOLOR="white" vlink="#000000" link="#04289D">
 
@@ -40,7 +41,7 @@ print CLIENT <<EOF
 	  <TD WIDTH="86" VALIGN="TOP">
 	    <TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0">
 		<TR>
-		    <TD WIDTH="86"><A HREF="http://www.wwdsi.com"><IMG SRC="$HTML_ROOT/images/wwdsi_logo.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="WWDSI"
+		    <TD WIDTH="86"><A HREF="http://www.saintcorporation.com"><IMG SRC="$HTML_ROOT/images/home.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="SAINT Corporation"
 			BORDER="0"></A></TD>
 		</TR>
 		<TR>
@@ -100,7 +101,7 @@ File containing list of target host(s):
 
 <DL compact>
 <DT><DD><input color=white type=radio name="attack_proximate_subnets" value="0" $check_subnets[0]>
-	Scan the target host(s) only.
+	Scan the target host(s) only. (Disables smurf check.)
 
 <DT><DD><input type=radio name="attack_proximate_subnets" value="1" $check_subnets[1]>
 	Scan all hosts in the target hosts' subnet(s).
@@ -125,11 +126,32 @@ Should SAINT do a light scan, a normal scan, or should it hit the
 <DT><DD><input type=radio name="attack_level" value="3" $check_level[3]>
 	Heavy+ (doesn't avoid WinNT ports that are known to crash system)
 <DT><DD><input type=radio name="attack_level" value="4" $check_level[4]>
-	Top 10 (scans specifically for
-	<A HREF="http://www.sans.org/topten.htm">SANS Top 10 Internet
-	Security Threats</A>)
+	Top 20 (scans specifically for
+	<A HREF="http://www.sans.org/top20.htm">SANS Top 20 Internet
+	Security Vulnerabilities</A>)
+<DT><DD><input type=radio name="attack_level" value="5" $check_level[5]>
+	Custom: <SELECT NAME=custom_level>
+EOF
+;
+for (@custom_levels) {
+	$selected = ($custom_level eq $_) ? " selected" : "";
+	print CLIENT "<OPTION$selected>$_</OPTION>\n";
+}
+print CLIENT <<EOF
+</SELECT>
+(<A HREF="../admin/saint_custom_select.pl,run,$rnd">Set up custom scan</A>)
+</DL>
+<P>
+Should SAINT perform <A HREF="$HTML_ROOT/docs/saint.cf.html#extreme-list">dangerous
+tests</A>? Dangerous tests may help
+reduce false alarms, but <b>may crash services on target hosts!</b>
+<P>
+<DL compact>
+<DT><DD><input type=radio name="extreme" value="0" $check_extreme[0]>
+	Do not perform dangerous tests. Just issue warnings of potential problems instead.
+<DT><DD><input type=radio name="extreme" value="1" $check_extreme[1]>
+	Perform dangerous tests.
 </DL>
-
 <HR>
 
 <h3>Firewall Support </h3>
@@ -138,13 +160,25 @@ Is the host you are scanning behind a firewall?  If it is, you should enable
 firewall support, or your results might not be accurate, or you might get
 no results at all.
 
-<Dl compact>
+<DL compact>
 <DT><DD><input type=radio name="firewall_flag" value="0" $check_firewall[0]>
 	No Firewall Support
 <DT><DD><input type=radio name="firewall_flag" value="1" $check_firewall[1]>
 	Firewall Support
 </DL>
+<HR>
+<h3>Windows Domain Authentication</h3>
 
+If you wish to perform a more thorough assessment of Windows
+targets, then <A HREF="$HTML_ROOT/docs/saint.cf.html#domain_user">authenticate</A>
+using the login name and password of a domain administrator. <I>See
+<A HREF="$HTML_ROOT/docs/saint.cf.html#domain_user_warn">security warning</A></I>.
+
+<DL compact>
+<DT><DD>Login: <input type=text name="domain_user" value="$domain_user" size=16>
+<DT><DD>Password: <input type=password name="domain_pass" size=16>
+</DL>
+<P>
 <INPUT TYPE="submit" VALUE=" Start the scan ">
 </FORM>
 </UL></UL>
