@@ -21,7 +21,7 @@ print <<EOF
 	  <TD WIDTH="86" VALIGN="TOP">
 	    <TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0">
 		<TR>
-		    <TD WIDTH="86"><A HREF="http://www.wwdsi.com"><IMG SRC="$HTML_ROOT/images/wwdsi_logo.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="WWDSI"
+		    <TD WIDTH="86"><A HREF="http://www.saintcorporation.com"><IMG SRC="$HTML_ROOT/images/home.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="SAINT Corporation"
 			BORDER="0"></A></TD>
 		</TR>
 		<TR>
@@ -63,18 +63,13 @@ print <<EOF
 		</DL>
 			<BLOCKQUOTE>
 				<P><SPAN STYLE="Margin-Bottom : 0px    ; Margin-Top : 0px    ; Padding-Bottom : 0px    ; Padding-Left : 0px    ; Padding-Right : 0px    ; Padding-Top : 0px"><FONT
-				COLOR="navy">The Security Administrator's Integrated Network<BR>
-				<BR>
-				Tool (SAINT) is designed to assess the security<BR>
-				<BR>
-				of computer networks. SAINT is a highly evolved<BR>
-				<BR>
+				COLOR="navy">The Security Administrator's Integrated Network
+				Tool (SAINT) is designed to assess the security
+				of computer networks. SAINT is a highly evolved
 				version of its predecessor </FONT></SPAN><A HREF="http://www.fish.com/satan/"><SPAN STYLE="Margin-Bottom : 0px    ; Margin-Top : 0px    ; Padding-Bottom : 0px    ; Padding-Left : 0px    ; Padding-Right : 0px    ; Padding-Top : 0px"><FONT
 				COLOR="#3366FF">SATAN</FONT></SPAN></A><SPAN STYLE="Margin-Bottom : 0px    ; Margin-Top : 0px    ; Padding-Bottom : 0px    ; Padding-Left : 0px    ; Padding-Right : 0px    ; Padding-Top : 0px"><FONT
 				COLOR="#3366FF">. </FONT></SPAN><SPAN STYLE="Margin-Bottom : 0px    ; Margin-Top : 0px    ; Padding-Bottom : 0px    ; Padding-Left : 0px    ; Padding-Right : 0px    ; Padding-Top : 0px"><FONT
-				 COLOR="navy">SAINT is <BR>
-				<BR>
-				indispensable for checking system vulnerabilities. 
+				COLOR="navy">SAINT is indispensable for checking system vulnerabilities. 
 				<TABLE ALIGN="LEFT" BORDER="0" CELLPADDING="0" CELLSPACING="0" WIDTH="423" HEIGHT="75">
 					<TR>
 						<TD WIDTH="19" HEIGHT="32">&nbsp;</TD>
@@ -84,7 +79,7 @@ print <<EOF
 						<TD WIDTH="19" HEIGHT="20" VALIGN="TOP">
 							<P ALIGN="RIGHT"><IMG SRC="$HTML_ROOT/images/bullet.gif" WIDTH="19" HEIGHT="20" ALIGN="BOTTOM" BORDER="0">
 						</TD>
-						<TD WIDTH="404" HEIGHT="20" VALIGN="TOP"><A HREF="http://www.wwdsi.com/saint/"><FONT COLOR="#3366FF">Getting the Latest Version
+						<TD WIDTH="404" HEIGHT="20" VALIGN="TOP"><A HREF="http://www.saintcorporation.com/saint/"><FONT COLOR="#3366FF">Getting the Latest Version
 							of SAINT</FONT></A></TD>
 					</TR>
 					<TR>
@@ -96,7 +91,7 @@ print <<EOF
 							<P ALIGN="RIGHT"><IMG SRC="$HTML_ROOT/images/bullet.gif" WIDTH="19" HEIGHT="20" ALIGN="BOTTOM" BORDER="0">
 						</TD>
 						<TD WIDTH="404" HEIGHT="20" VALIGN="TOP"><FONT COLOR="#3366FF">SAINT&#153; includes</FONT><A HREF="$HTML_ROOT/docs/FAQ.html#cve"><FONT COLOR="#3366FF">
-							CVE numbers</FONT></A><BR><FONT COLOR="#3366FF"> and scans for the </FONT><A HREF="$HTML_ROOT/docs/FAQ.html#top10"><FONT COLOR="#3366FF">Top 10
+							CVE numbers</FONT></A><BR><FONT COLOR="#3366FF"> and scans for the </FONT><A HREF="$HTML_ROOT/docs/FAQ.html#top20"><FONT COLOR="#3366FF">Top 20
 							Vulnerabilities</FONT></A><FONT COLOR="#3366FF">.</FONT><BR><A HREF="$HTML_ROOT/docs/cve.html"><FONT COLOR="#3366FF">(Which CVEs can SAINT detect?)</FONT></A>
 						</TD>
 					</TR>
@@ -108,8 +103,12 @@ print <<EOF
 						<TD WIDTH="19" HEIGHT="35" VALIGN="TOP">
 							<P ALIGN="RIGHT"><IMG SRC="$HTML_ROOT/images/bullet.gif" WIDTH="19" HEIGHT="20" ALIGN="BOTTOM" BORDER="0">
 						</TD>
-						<TD WIDTH="404" HEIGHT="35" VALIGN="TOP"><A HREF="http://www.wwdsi.com/about/customer_eval.html"><FONT COLOR="#3366FF">
-							We'd like to hear from you!</FONT></A></TD>
+						<TD WIDTH="404" HEIGHT="35" VALIGN="TOP"><A HREF="$HTML_ROOT/docs/authors.html"><FONT COLOR="#3366FF">
+							About the SAINT Team</FONT></A></TD>
+					</TR>
+					<TR>
+						<TD WIDTH="19">&nbsp;</TD>
+						<TD WIDTH="404"><CENTER><IMG SRC="$HTML_ROOT/images/sans.gif" ALT="SANS"><A HREF="http://cve.mitre.org"><IMG SRC="$HTML_ROOT/images/cve.gif" ALT="CVE"></A></CENTER></TD>
 					</TR>
 EOF
 ;
