@@ -2,7 +2,7 @@ print <<EOF
 <HTML>
 <HEAD>
 <title>SAINT</title>
-<LINK REV="made" HREF="mailto:saint\@wwdsi.com">
+<LINK REV="made" HREF="mailto:saint\@saintcorporation.com">
 </HEAD>
 <BODY BGCOLOR="white" vlink="#000000" link="#04289D">
 
@@ -17,7 +17,7 @@ print <<EOF
 	  <TD WIDTH="86" VALIGN="TOP">
 	    <TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0">
 		<TR>
-		    <TD WIDTH="86"><A HREF="http://www.wwdsi.com"><IMG SRC="$HTML_ROOT/images/wwdsi_logo.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="WWDSI"
+		    <TD WIDTH="86"><A HREF="http://www.saintcorporation.com"><IMG SRC="$HTML_ROOT/images/home.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="SAINT Corporation"
 			BORDER="0"></A></TD>
 		</TR>
 		<TR>
