@@ -143,7 +143,9 @@ sub merge_facts {
 				$nb_name{$target}=$text if ($service_output eq "Netbios Name");
 				&update_severities($_);
 				&update_trust($_);
-				&infer_facts($_);
+				# Removed to avoid discrepancy between facts
+				# in memory and facts in file (4/02)
+				#&infer_facts($_);
 			}
 		}
 	}
@@ -156,7 +158,7 @@ sub merge_facts {
 #
 sub drop_old_facts {
 	local($host) = @_;
-	local($fact, $target);
+	local($fact, $target, $network);
 
 	for $fact (keys %old_facts) {
 		($target) = split(/\|/, $fact);
@@ -164,6 +166,14 @@ sub drop_old_facts {
 			print "Deleting: $fact\n" if $debug;
 			delete $old_facts{$fact};
 		}
+		# check associated network/broadcast addresses
+		# (s.k. 8/00)
+		for $network (&get_all_networks($host)) {
+		    if ($target eq $network) {
+			print "Deleting: $fact\n" if $debug;
+			delete $old_facts{$fact};
+		    }
+		}
 	}
 }
 
