@@ -31,7 +31,7 @@ sub build_infer_hosttype {
 
     $code = "sub infer_hosttype {\n";
     $code .= "\tlocal(\$type);\n";
-    $code .= "\tif (\$service !~ /^(smtp|telnet|ftp|nmap|netbios-ssn|snmp)\$/) {\n\t\treturn;\n\t}\n";
+    $code .= "\tif (\$service !~ /^(smtp|telnet|ftp|nmap|smurf|netbios-ssn|snmp)\$/) {\n\t\treturn;\n\t}\n";
     $class = "other";
 
     foreach $file (split(/\s+/, $files)) {
@@ -56,7 +56,7 @@ sub build_infer_hosttype {
 		$type = "\$1" if ($type eq "");
 		$code .= "\
 	if ($cond) {
-		\$type = $type;
+		(\$type = $type) =~ s/[^-_ ,a-zA-Z0-9:.!\"\\/]//g;
 		\$hosttype{\$target} = \$type; 
 		\$sysclass{\$type} = \"$class\";
 		\$hosttype_flag = 0;
