@@ -1,4 +1,4 @@
-#!/usr/bin/perl5.00502
+#!/usr/bin/perl
 #
 #
 
@@ -37,12 +37,12 @@ sub html {
 	$html_root = "$wd/html";
 	$start_page = "saint.html";
 	$auth_page = "auth/saint_auth_form.pl";
-	$THIS_HOST = &getfqdn(&hostname());
-	$THIS_HOST = $my_address unless $THIS_HOST;
+	$THIS_HOST = $my_address;
+	$THIS_HOST = &getfqdn(&hostname()) unless $THIS_HOST;
 	die "Can't find my own hostname: set \$dont_use_nslookup or \$my_address in $SAINT_CF\n"
 	    unless $THIS_HOST;
 	if ($remote_mode) {
-	    $HTML_SERVER = "http://$THIS_HOST:$html_port/$html_root";
+	    $HTML_SERVER = "http://$THIS_HOST:$server_port/$html_root";
 	    $HTML_ROOT = $HTML_SERVER;
 	    $HTML_STARTPAGE = "$HTML_ROOT/$start_page";
 	    $HTML_AUTHPAGE = "$HTML_ROOT/$auth_page";
@@ -79,9 +79,9 @@ sub html {
 	# handles requests from that client. The parent process waits
 	# until the client exits and terminates the server.
 	#
-	print "Starting $MOSAIC...\n" if $debug;
 
 	if (! $remote_mode) {
+	    print "Starting $MOSAIC...\n" if $debug;
 	    if (($client = fork()) == 0) {
 		foreach (keys %ENV) {
 			delete $ENV{$_} if (/proxy/i && !/no_proxy/i);
@@ -99,19 +99,56 @@ sub html {
 		&read_saint_data() unless defined($opt_i);
 		kill 'TERM',$helper;
 		$SIG{'PIPE'} = 'IGNORE';
-		for (;;) {
+		unless ($web_server) {
+		    for (;;) {
 			accept(CLIENT, SOCK) || die "accept: $!";
 			select((select(CLIENT), $| = 1)[0]);
 			&process_html_request();
 			close(CLIENT);
+		    }
+		} else {
+		    for (;;) {
+			# wait for a query from the pipe
+			open(QUERY, "< $query_pipe")
+			    || die "cannot open query pipe";
+			chomp($pipe_ext = <QUERY>);
+			open(CLIENT, "> /tmp/$response_pipe.$pipe_ext")
+			    || die "Cannot open response pipe /tmp/$response_pipe.$pipe_ext";
+			&process_html_request();
+			close QUERY;
+			close CLIENT;
+		    }
 		}
 	}
 
 	#
-	# Wait until the client terminates, then terminate the server.
+	# In remote mode, log PID and port in saint.pid and
+	# exit. Otherwise, wait until the client terminates,
+        # then terminate the server.
 	#
 	close(SOCK);
-	if (! $remote_mode) {
+	if ($remote_mode) {
+	  if ($web_server) {
+	    # Check whether SAINT is already running
+	    open(PID, "< config/saint.pid");
+	    while(<PID>) {
+	      if (/\d+:$/) {
+		warn "There seem to be multiple SAINT processes running;\n";
+		warn "This could cause unpredictable behavior\n";
+		break;
+	      }
+	    }
+	    close PID;
+	  }
+	  if (!open(PID, ">> config/saint.pid")) {
+	    warn "Could not open config/saint.pid; -k option won't work\n";
+	  } else {
+	    ($web_server && print PID "$server:\n")
+		|| print PID "$server:$server_port\n";
+	    close PID;
+	  }
+	}
+	else {
 	  waitpid($client, 0);
 	  kill('TERM', $server);
 	}
@@ -126,7 +163,7 @@ sub html {
 sub make_password_seed {
 	local($command);
 
-	die "Cannot find $MD5. Did you run a \"reconfig\" and \"make\"?\n"
+	die "Cannot find $MD5. Did you run \"configure\" and \"make\"?\n"
 		unless -x "$MD5";
 	$command = "ps axl&ps -el&netstat -na&netstat -s&ls -lRt /dev*&w";
 	open(SEED, "($command) 2>/dev/null | $MD5 |")
@@ -143,16 +180,67 @@ sub make_password_seed {
 sub start_html_server {
 	local($sockaddr, $proto, $junk);
 
+    if (!$web_server) {
 	$sockaddr = 'S n a4 x8';
 	($junk, $junk, $proto) = getprotobyname('tcp');
-	socket(SOCK, &AF_INET, &SOCK_STREAM, $proto) || die "socket: $!";
+	socket(SOCK, &_AF_INET, &_SOCK_STREAM, $proto) || die "socket: $!";
 	if ($remote_mode) {
-		$binder = pack($sockaddr, &AF_INET, $server_port, "\0\0\0\0");
+		$binder = pack($sockaddr, &_AF_INET, $server_port, "\0\0\0\0");
 		bind(SOCK, $binder) || die "bind: $!";
 		print "Starting SAINT server on port $server_port\n";
 	}
 	listen(SOCK, 1) || die "listen: $!";
 	($junk, $html_port) = unpack($sockaddr, getsockname(SOCK));
+    } else {
+	# Instead of listening on a port, create named pipe
+	# for receiving queries
+	unless (-p "$query_pipe") {
+	    unlink "$query_pipe";
+	    if (-x "$MKFIFO") {
+		system($MKFIFO, $query_pipe)
+		&& die "Cannot create named pipe $query_pipe";
+	    } elsif (-x "$MKNOD") {
+		system($MKNOD, $query_pipe, "p")
+		&& die "Cannot create named pipe $query_pipe";
+	    } else {
+		die "Cannot execute $MKNOD or $MKFIFO";
+	    }
+	}
+    }
+}
+
+#
+# Kill the HTML server on specified port as
+# defined in saint.pid (All ports if none specified)
+#
+sub stop_html_server {
+	my($port) = @_;
+	my($pid, $p);
+
+	if (!open(PID, "< config/saint.pid")) {
+	    warn "Could not open config/saint.pid\n";
+	    return;
+	}
+	if (!open(NEWPID, "> config/saint.pid.new")) {
+	    warn "Could not create new config/saint.pid\n";
+	    return;
+	}
+	while(<PID>) {
+	    ($pid, $p) = split /:/;
+	    if (!$port || !$p || $p==$port) {
+		if (kill 'TERM', $pid) {
+		    ($p =~ /\d/ && print "Stopped SAINT server on port $p\n")
+		    || print "Stopped SAINT process ID $pid\n";
+		} else {
+		    warn "Could not kill process $pid\n";
+		}
+	    } else {
+		print NEWPID;
+	    }
+	}
+	close PID;
+	close NEWPID;
+	system("mv config/saint.pid.new config/saint.pid");
 }
 
 #
@@ -174,7 +262,13 @@ sub process_html_request {
 	#
 	# Parse the command and URL. Update the default file prefix.
 	#
-	$request = <CLIENT>;
+	unless ($web_server) {
+	    $peer = &get_peer_addr(CLIENT);
+	    $request = <CLIENT>;
+	} else {
+	    chomp($peer = <QUERY>);
+	    $request = <QUERY>;
+	}
 	print $request if $debug;
 	($command, $url) = split(/\s+/, $request);
 	if ($command eq "" || $command eq "QUIT") {
@@ -184,7 +278,6 @@ sub process_html_request {
 	#
 	# Make sure they gave us the right magic number.
 	#
-	$peer = &get_peer_addr(CLIENT);
 	if (!$remote_mode) {
 	    ($junk, $magic, $script) = split(/\//, $url, 3);
 	    if ($magic ne $html_password) {
@@ -221,9 +314,11 @@ sub process_html_request {
 	}
 
 	#
+	# Process HTTP headers
 	# Warn them when the browser leaks parent URLs to web servers.
 	#
-	while (<CLIENT>) {
+	unless ($web_server) {
+	    while (<CLIENT>) {
 		if (!$cookie_leak_warning && /$html_password/) {
 			&flush_http_input();
                         send_http_header("200 OK");
@@ -232,6 +327,12 @@ sub process_html_request {
 		}
 		$length = $1 if (/Content-length:\s*([0-9]+)/i);
 		last if (/^\s+$/);
+	    }
+	} else {
+	    while (<QUERY>) {
+		$length = $1 if (/Content-length:\s*([0-9]+)/i);
+		last if (/^\s+$/);
+	    }
 	}
 
 	# if using remote mode, check that we are authenticated
@@ -239,7 +340,6 @@ sub process_html_request {
 	    if (!defined($authenticated{$peer})) {
 		if ($script !~ /^$html_root\/auth/ &&
 	            $script !~ /^$html_root\/images\//) {
-		  send_http_header("200 OK");
 		  &auth_required();
 		  return;
 		}
@@ -247,7 +347,6 @@ sub process_html_request {
 		if ($script =~ /\/running\// ||
 		    $script =~ /\/data\// ||
 		    $script =~ /\/admin\//) {
-		  send_http_header("200 OK");
 		  &admin_required();
 		  return;
 		}
@@ -259,6 +358,8 @@ sub process_html_request {
 			&send_file("image/jpeg", $script);
 		} elsif ($script =~ /\.gif$/i) {
 			&send_file("image/gif", $script);
+		} elsif ($script =~ /\.png$/i) {
+			&send_file("image/png", $script);
 		} elsif ($script =~ /\.html$/i) {
 			&send_file("text/html", $script);
 		} elsif ($script =~ /\.pl$/i) {
@@ -271,8 +372,13 @@ sub process_html_request {
 		#
 		# Process the attribute-value list.
 		#
-		read CLIENT, $_, $length;
+		unless ($web_server) {
+		    read CLIENT, $_, $length;
+		} else {
+		    read QUERY, $_, $length;
+		}
 		if ($_) {
+			s/%0[ad]//ig;
 			s/\s+$//;
 			s/^/\n/;
 			s/&/\n/g;
@@ -306,6 +412,7 @@ sub process_html_request {
 	} else {
 		&bad_html_command($request);
 	}
+	close CLIENT if $web_server;
 }
 
 
@@ -336,11 +443,13 @@ sub get_peer_addr {
 #
 sub send_http_header {
     my($error)=@_;
+    my($message);
 
+    print CLIENT "HTTP-server: $HTML_SERVER\n" if $web_server;
     print CLIENT <<EOF;
 HTTP/1.0 $error
 Content-type: text/html
-Server: SAINT/2.1.x
+Server: SAINT/3.5.x
 
 EOF
 }
@@ -353,7 +462,7 @@ sub send_file {
     my($type, $sourcepath)=@_;
 
     if (! -e $sourcepath) {
-	send_http_header("404 File not found");
+	send_http_header("404 Not Found");
 	print CLIENT <<EOF;
 <HTML>
 <HEAD>
@@ -369,10 +478,11 @@ EOF
     }
     $sourcelen = (-s "$sourcepath");
 
+    print CLIENT "HTTP-server: $HTML_SERVER\n" if $web_server;
     print CLIENT <<EOF;
 HTTP/1.0 200 OK
 Content-type: $type
-Server: SAINT/2.1
+Server: SAINT/3.5.x
 Content-length: $sourcelen
 
 EOF
@@ -398,6 +508,7 @@ sub bad_html_magic {
 	$peer = &get_peer_addr(CLIENT);
 	print STDERR "bad request from $peer: $request\n";
 
+	send_http_header("401 Unauthorized");
         print CLIENT <<EOF
 <HTML>
 <HEAD>
@@ -418,6 +529,7 @@ EOF
 sub bad_html_command {
 	local($request) = @_;
 
+	send_http_header("501 Not Implemented");
 	print CLIENT <<EOF
 <HTML>
 <HEAD>
@@ -439,7 +551,7 @@ sub perl_html_script {
 	local($script) = @_;
 
 	if (! -e $script) {
-                send_http_header("404 Script Not Found");
+                send_http_header("404 Not Found");
 		print CLIENT <<EOF
 <HTML>
 <HEAD>
@@ -454,7 +566,9 @@ The file <TT>$script</TT> does not exist or is not accessible.
 EOF
 ;		return;
 	}
-        send_http_header("200 OK");
+        send_http_header("200 OK")
+	    unless $script =~ /saintwriter_action/;
+	    # saintwriter_action sends its own headers
 	do $script;
 	if ($@ && ($@ ne "\n")) {
 		print CLIENT <<EOF
@@ -478,6 +592,7 @@ EOF
 sub bad_html_form {
 	local($script) = @_;
 
+	send_http_header("400 Bad Request");
 	print CLIENT <<EOF
 <HTML>
 <HEAD>
@@ -521,9 +636,16 @@ if ($running_under_saint == 1) {
 #
 sub patience {
 	for (;;) {
+	    unless ($web_server) {
 		accept(CLIENT, SOCK) || die "accept: $!";
 		<CLIENT>;
-		print CLIENT <<EOF
+	    } else {
+		open(QUERY, "< $query_pipe") ||
+		    die "Cannot open query pipe";
+		<QUERY>;
+	    }
+	    send_http_header("200 OK");
+	    print CLIENT <<EOF
 <HTML>
 <HEAD>
 <TITLE>Server is busy</TITLE>
@@ -538,6 +660,7 @@ or processing another request.  Please try again later.
 EOF
 ;
 		close(CLIENT);
+		close QUERY if $web_server;
 	}
 }
 
@@ -581,6 +704,7 @@ sub flush_http_input {
 }
 
 sub auth_required {
+	send_http_header("401 Unauthorized");
 	print CLIENT <<EOF;
 <HTML>
 <HEAD>
@@ -600,6 +724,7 @@ EOF
 }
 
 sub admin_required {
+	send_http_header("403 Forbidden");
 	print CLIENT <<EOF;
 <HTML>
 <HEAD>
@@ -619,6 +744,7 @@ EOF
 }
 
 sub host_denied {
+	send_http_header("403 Forbidden");
 	print CLIENT <<EOF;
 <HTML>
 <HEAD>
@@ -633,6 +759,7 @@ EOF
 }
 
 sub illegal_url {
+	send_http_header("400 Bad Request");
 	print CLIENT <<EOF;
 <HTML>
 <HEAD>
