@@ -12,6 +12,7 @@ require 'perl/suser.pl';
 sub run_saint {
 	local($primaries) = @_;
 	local($target);
+	my($target_addr);
 
 	#
 	# Don't die silently when tools cannot be run with sufficient privilege.
@@ -33,9 +34,12 @@ sub run_saint {
 		# in reality called bar.foo.com.
 		#
 		if ($primary_target =~ /^[a-zA-Z]+.*|^\d+\.\d+\.\d+\.\d+$/) {
+		    $target_addr = &get_host_addr($primary_target);
+		    if ($target = &getfqdn(&get_host_name($target_addr))) {
+			# check that fqdn resolves back to original target
 			$primary_target = $target
-			    if ($target = &getfqdn(&get_host_name(
-				    &get_host_addr($primary_target))));
+			    if &get_host_addr($target) eq $target_addr;
+		    }
 		}
 
 		# schedule probe assignments...
