@@ -45,6 +45,7 @@ sub clear_saint_data {
 	&clear_facts();
 	&clear_todos();
 	&clear_cves();
+	&clear_exclusions();
 }
 
 #
@@ -67,6 +68,7 @@ sub drop_saint_data {
 #
 sub read_saint_data {
 
+	my($exclusions_file) = &exclusion_file_path;
 	&clear_saint_data();
 
 	print "Reading $saint_data files...\n" if (-s $facts_file && $debug);
@@ -75,6 +77,7 @@ sub read_saint_data {
 	&read_facts($facts_file) if -f $facts_file;
 	&read_todos($todo_file) if -f $todo_file;
 	&read_cves($cve_file) if -f $cve_file;
+	&read_exclusions($exclusions_file) if -f $exclusions_file;
 
 	print "Done reading $saint_data files\n" if (-s $facts_file && $debug);
 }
@@ -104,8 +107,12 @@ sub save_saint_data {
 # Merge data with in-core tables.
 #
 sub merge_saint_data {
+	my($exclusions_file) = &exclusion_file_path;
+
 	&merge_all_hosts($all_hosts_file) if -f $all_hosts_file;
 	&merge_facts($facts_file) if -f $facts_file;
 	&merge_todos($todo_file) if -f $todo_file;
 	&merge_cves($cve_file) if -f $cve_file;
+	&merge_exclusions($exclusions_file) if -f $exclusions_file;
+	&force_recalc;
 }
