@@ -13,7 +13,7 @@ require 'perl/status.pl';
 sub bad_cmd {
 	local($command) = @_;
 
-	return ($command =~ /[^-_ ,a-zA-Z0-9:.!\/]/);
+	return ($command =~ /[^-_ ,a-zA-Z0-9:.!"\/]/);
 }
 		
 sub open_cmd {
@@ -29,6 +29,9 @@ sub open_cmd {
 	} else {
 		$ret = open($handle, "$shell_cmd|");
 	}
+	if ($shell_cmd =~ /registry.saint/) {
+	    $shell_cmd =~ s/ -p \".*\"/ -p ********/;
+	}
 	&update_status("$shell_cmd");
 	print "==> running $shell_cmd\n" if $debug;
 	return $ret;
