@@ -12,10 +12,13 @@ require $SAINT_CF;
 #
 sub hhmmss {
 	local($time) = @_;
-	local($sec, $min, $hour);
+	local($sec, $min, $hour, $day, $month, $year);
 	
-	($sec, $min, $hour) = localtime($time);
-	return sprintf "%02d:%02d:%02d", "$hour", "$min", "$sec";
+	($sec, $min, $hour, $day, $month, $year) = localtime($time);
+	$year = $year % 100;
+	$month = $month + 1;
+	return sprintf "%02d/%02d/%02d-%02d:%02d:%02d",
+		"$month", "$day", "$year", "$hour", "$min", "$sec";
 }
 
 sub update_status {
