@@ -1,7 +1,3 @@
-#  Portions of this program were developed by the Advanced Research
-# Corporation (r).  Use of this routine to wwdsi is authorized until
-# 1 Jan 99.
-
 # perl/todo.pl
 # add_todo($record) add one record to the new todo list.
 # save_todos($path) saves the old todos to the named file.
@@ -56,9 +52,14 @@ while (sizeof(*new_todos) > 0) {
 	%children = ();
 	for $key (keys %temp_todos) {
 		($target, $tool, $args) = split(/\|/, $temp_todos{$key}, 3);
-		next unless exists($all_hosts{$target});
-		$level = $all_hosts{$target}{'attack'};
-		next unless $level >= 0;
+		if ($target =~ /^[\d\.]+\/$/) {
+		    # target is a network address
+		    next unless $attack_proximate_subnets;
+		} else {
+		    next unless exists($all_hosts{$target});
+		    $level = $all_hosts{$target}{'attack'};
+		    next unless $level >= 0;
+		}
 		for $probe (@{$all_attacks[$level]}) {
 			if ($tool eq $probe || "$tool?" eq $probe || $probe eq "*?") {
 			    $old_todos{$key} = 1;
@@ -106,8 +107,15 @@ while (sizeof(*new_todos) > 0) {
 	    for $child (keys %children) {
 		if (open (TEMPFACTS, "facts.$child")) {
 			while (<TEMPFACTS>) {
+			    # if the program starved, give it
+			    # another chance, running alone */
+			    if (/^(.+)\|(.+)\|u\|\|\|\|\|program did not run \((.*)\)$/) {
+				&set_host_time($1);
+				&run_next_todo($1,$2,$3,1);
+			    } else {
 				chop;
 				&add_fact($_);
+			    }
 			}
 			close(TEMPFACTS);
 			unlink "facts.$child";
@@ -143,11 +151,15 @@ sub clear_todos {
 #
 sub drop_old_todos {
 	local($host) = @_;
-	local($key, $target, $tool, $args);
+	local($key, $target, $tool, $args, $network);
 
 	for $key (keys %old_todos) {
 		($target, $tool, $args) = split(/\|/, $key);
 		delete $old_todos{$key} if $target eq $host;
+		# delete associated network address
+		# (s.k. 8/00)
+		$network = &get_network($host) . "/";
+		delete $old_todos{$key} if $target eq $network;
 	}
 }
 
@@ -181,7 +193,7 @@ close(TODO);
 #
 sub run_next_todo
 {
-local($target, $tool, $args) = @_;
+local($target, $tool, $args, $alone) = @_;
 local($text, $ttl);
 
 if ($tool =~ /^([^\. ]+)/) { $timeout_var = $1 . "_timeout"; }
@@ -193,7 +205,7 @@ $command = "bin/$tool $args $target";
 $fflag="";
 if ($firewall_flag) {
    $fflag="FW";
-   if ($tool =~ $heavy_tcp_scan) {
+   if ($tool =~ /tcpscan.saint/) {
          $ttl=$fw_tcp_scan;
    }
 }
@@ -207,18 +219,24 @@ $command="$command $fflag";
 die "Can't run $tool\n" unless &open_cmd(TOOL, $ttl, $command);
 
 # if not multitasking, just add each facts from tool
-if ($maximum_threads <= 1) {
+if ($maximum_threads <= 1 || $alone) {
+    $begun = 1;
     while (<TOOL>) {
 	chop;
-	&add_fact($_);
+	&add_fact($_) unless /^BEGIN$/;
 	}
 }
 
 # if multitasking, create an output file from each tool
 else {
+    $begun = 0;
     open(TEMPFACTS, "> facts.$$");
     while (<TOOL>) {
-	print TEMPFACTS;
+	if (/^BEGIN$/) {
+	    $begun = 1;
+	} else {
+	    print TEMPFACTS;
+	}
     }
     close (TEMPFACTS);
 }
@@ -229,13 +247,19 @@ close(TOOL);
 # If the former, assume that we need to output an error record...
 if ($?) {
 	# based on exit value, decide what happened:
-	if ($? == $timeout_kill) { $text = "program timed out"; }
+	if ($? == $timeout_kill) {
+	    if ($begun) {
+		$text = "program timed out";
+	    } else {
+		$text = "program did not run ($args)";
+	    }
+	}
 	elsif ($? > 0 && $? < $timeout_kill) {
 		$text = "internal program error $?";
-		}
+	}
 	else { $text = "unknown error #$?"; }
  
-	if ($maximum_threads <= 1) {
+	if ($maximum_threads <= 1 || $alone) {
 		&add_fact("$target|$tool|u|||||$text");
 	} else {
 		open(TEMPFACTS, ">> facts.$$");
