@@ -5,6 +5,7 @@
   * Author: Wietse Venema.
   * Additions: Carson & Associates (Margaret Lord [MDL] and Bob Todd [RET])
   *
+  * Modified by Sam Kline, WWDSI, 7/01: Added -T option
   */
 
 #include <sys/types.h>
@@ -50,7 +51,7 @@ extern char *strerror();
 
 #include "lib.h"
 
-#define BANNER_LENGTH	2048		/* upper bound on banner info */
+#define BANNER_LENGTH	4096		/* upper bound on banner info */
 #define BANNER_TIME	10		/* time for host to send banner */
 #define BANNER_IDLE	1		/* delay after last banner info */
 
@@ -75,6 +76,7 @@ int     ports_done;			/* number of finished sockets */
 int     max_sock;			/* max socket file descriptor */
 int     want_err;			/* want good/bad news */
 int     show_all;			/* report all ports */
+int	telnet_options = 0;		/* show telnet options */
 
 int    *socket_to_port;			/* socket to port number */
 
@@ -127,7 +129,7 @@ char   *argv[];
     open_file_limit = open_limit();
     load_limit = open_file_limit - 10;
 
-    while ((c = getopt(argc, argv, "abl:f:s:t:uUvw:")) != EOF) {
+    while ((c = getopt(argc, argv, "abl:f:s:t:TuUvw:")) != EOF) {
 	switch (c) {
 	case 'a':
 	    show_all = 1;
@@ -158,6 +160,9 @@ char   *argv[];
 	    if ((response_time = atoi(optarg)) <= 0)
 		usage("invalid timeout");
 	    break;
+	case 'T':
+	    telnet_options = 1;
+	    break;
 	case 'u':
 	    want_err = EHOSTUNREACH;
 	    break;
@@ -230,7 +235,7 @@ char   *why;
     if (why)
 	remark(why);
     /* MDL 5/25/98 updated usage */
-    error("usage: %s [-abuUv] [-l load] [-f connect time] [-s send string] [-w banner time] host ports...", progname);
+    error("usage: %s [-abTuUv] [-l load] [-f connect time] [-s send string] [-w banner time] host ports...", progname);
 }
 
 /* scan_ports - scan ranges of ports */
@@ -379,7 +384,8 @@ int     wait;
         }
 	for (sock = 0; ports_busy > 0 && sock <= max_sock; sock++) {
 	    if (FD_ISSET(sock, &write_mask)) {
-		if (read(sock, &ch, 1) < 0 && errno != EWOULDBLOCK && errno != EAGAIN) {
+		if (read(sock, &ch, 1) < 0 && errno != EWOULDBLOCK && errno != EAGAIN
+			&& errno != ECONNRESET && errno != EPIPE) {
 		    report_and_drop_socket(sock, errno);
 		} else {
 		    report_and_drop_socket(sock, 0);
@@ -429,11 +435,13 @@ int     wait;
                 sock_time[sock]=0;
                 /* end of MDL added */
 		if (send_string)
-		    do_send_string(sock);
+		    if (do_send_string(sock) < 0)
+			report_and_drop_socket(sock, errno);
 	    } else if (FD_ISSET(sock, &read_mask)) {
 		switch (read_socket(sock)) {
 		case -1:
-		    if (errno != EWOULDBLOCK && errno != EAGAIN)
+		    if (errno != EWOULDBLOCK && errno != EAGAIN
+			&& errno != ECONNRESET && errno != EPIPE)
 			report_and_drop_socket(sock, errno);
 		    break;
 		case 0:
@@ -485,7 +493,7 @@ int     sock;
      */
 
     if ((count = read(sock, cp, 1)) == 1) {
-	if (cp[0] == IAC) {
+	if (!telnet_options && cp[0] == IAC) {
 	    if ((count = read(sock, cp + 1, 2)) == 2) {
 		if (cp[1] == WILL || cp[1] == WONT) {
 		    cp[1] = DONT;
@@ -692,7 +700,7 @@ int     sock;
 
 /* do_send_string - send the send string */
 
-do_send_string(sock)
+int do_send_string(sock)
 int     sock;
 {
     char    buf[BUFSIZ];
@@ -700,6 +708,7 @@ int     sock;
     char    ch;
     int     c;
     int     i;
+    int     ret;
     char   *s = send_string;
 
     while (*s && cp < buf + sizeof(buf) - 1) {	/* don't overflow the buffer */
@@ -729,5 +738,6 @@ int     sock;
 	    *cp++ = ch;
 	}
     }
-    write(sock, buf, cp - buf);
+    ret = write(sock, buf, cp - buf);
+    return(ret);
 }
